@@ -69,13 +69,10 @@ std::vector< Fish > next_pop_migr(const std::vector< Fish>& pop_1,
                                   bool multiplicative_selection,
                                   double migration_rate,
                                   std::vector< double >& new_fitness,
-                                  double& new_max_fitness,
                                   double size_in_morgan) {
 
   std::vector<Fish> new_generation(pop_size);
-  new_fitness.clear();
-  new_fitness.resize(pop_size);
-  new_max_fitness = -1.0;
+
   for (size_t i = 0; i < pop_size; ++i)  {
     int index1, index2;
     Fish parent1 = draw_parent(pop_1, pop_2, migration_rate,
@@ -100,7 +97,6 @@ std::vector< Fish > next_pop_migr(const std::vector< Fish>& pop_1,
 
     double fit = -2.0;
     if (use_selection) fit = calculate_fitness(new_generation[i], select, multiplicative_selection);
-    if (fit > new_max_fitness) new_max_fitness = fit;
 
     new_fitness[i] = fit;
   }
@@ -124,14 +120,14 @@ std::vector< std::vector< Fish > > simulate_two_populations(
     int num_alleles,
     const std::vector<int>& founder_labels,
     double migration_rate) {
-  bool use_selection = FALSE;
-  if (select(1, 1) >= 0) use_selection = TRUE;
+  bool use_selection = false;
+  if (select(1, 1) >= 0) use_selection = true;
 
   std::vector<Fish> pop_1 = source_pop_1;
   std::vector<Fish> pop_2 = source_pop_2;
 
-  double max_fitness_pop_1, max_fitness_pop_2;
-  std::vector<double> fitness_pop_1, fitness_pop_2;
+  std::vector<double> fitness_pop_1(pop_1.size(), 0.0);
+  std::vector<double> fitness_pop_2(pop_2.size(), 0.0);
 
   if (use_selection) {
     for (int j = 0; j < select.nrow(); ++j) {
@@ -144,21 +140,19 @@ std::vector< std::vector< Fish > > simulate_two_populations(
       }
     }
 
-    for (auto it = pop_1.begin(); it != pop_1.end(); ++it){
-      double fit = calculate_fitness((*it), select, multiplicative_selection);
-      if (fit > max_fitness_pop_1) max_fitness_pop_1 = fit;
-
-      fitness_pop_1.push_back(fit);
+    for (size_t i = 0; i < pop_1.size(); ++i) {
+      fitness_pop_1[i] = calculate_fitness(pop_1[i], select, multiplicative_selection);
     }
 
-    for (auto it = pop_2.begin(); it != pop_2.end(); ++it){
-      double fit = calculate_fitness((*it), select, multiplicative_selection);
-      if (fit > max_fitness_pop_2) max_fitness_pop_2 = fit;
-
-      fitness_pop_2.push_back(fit);
+    for (size_t i = 0; i < pop_2.size(); ++i) {
+      fitness_pop_2[i] = calculate_fitness(pop_2[i], select, multiplicative_selection);
     }
   }
 
+  double max_fitness_pop_1 = *std::max_element(fitness_pop_1.begin(), fitness_pop_1.end());
+  double max_fitness_pop_2 = *std::max_element(fitness_pop_2.begin(), fitness_pop_2.end());
+
+
   int updateFreq = total_runtime / 20;
   if(updateFreq < 1) updateFreq = 1;
 
@@ -189,10 +183,8 @@ std::vector< std::vector< Fish > > simulate_two_populations(
       }
     }
 
-    double new_max_fitness_pop_2 = 0.0;
-    double new_max_fitness_pop_1 = 0.0;
-
-    std::vector<double> new_fitness_pop_1, new_fitness_pop_2;
+    std::vector<double> new_fitness_pop_1(pop_1.size(), 0.0);
+    std::vector<double> new_fitness_pop_2(pop_2.size(), 0.0);
 
     std::vector<Fish> new_generation_pop_1 = next_pop_migr(pop_1, // resident
                                                            pop_2, // migrants
@@ -206,7 +198,6 @@ std::vector< std::vector< Fish > > simulate_two_populations(
                                                            multiplicative_selection,
                                                            migration_rate,
                                                            new_fitness_pop_1,
-                                                           new_max_fitness_pop_1,
                                                            morgan);
 
     std::vector<Fish> new_generation_pop_2 = next_pop_migr(pop_2,  // resident
@@ -221,14 +212,15 @@ std::vector< std::vector< Fish > > simulate_two_populations(
                                                            multiplicative_selection,
                                                            migration_rate,
                                                            new_fitness_pop_2,
-                                                           new_max_fitness_pop_2,
                                                            morgan);
     pop_1 = new_generation_pop_1;
     pop_2 = new_generation_pop_2;
     fitness_pop_1 = new_fitness_pop_1;
     fitness_pop_2 = new_fitness_pop_2;
-    max_fitness_pop_1 = new_max_fitness_pop_1;
-    max_fitness_pop_2 = new_max_fitness_pop_2;
+    max_fitness_pop_1 = *std::max_element(fitness_pop_1.begin(),
+                                          fitness_pop_1.end());
+    max_fitness_pop_2 = *std::max_element(fitness_pop_2.begin(),
+                                          fitness_pop_2.end());
 
     if (t % updateFreq == 0 && verbose) {
       Rcout << "**";
