@@ -1,6 +1,8 @@
 context("isoFemale creation")
 
 test_that("create_isofemale", {
+  testthat::skip_on_os("solaris")
+  message("testing create_isofemale")
   pop_size <- 100
   number_of_founders <- 2
   run_time <- 100
@@ -26,6 +28,8 @@ testthat::expect_silent(
 })
 
 test_that("create_population_from_isofemales", {
+  testthat::skip_on_os("solaris")
+  message("testing create_population_from_isofemales")
   pop_size <- 100
   number_of_founders <- 10
   run_time <- 100
@@ -84,6 +88,8 @@ testthat::expect_silent(
 })
 
 test_that("cpp classes", {
+  testthat::skip_on_os("solaris")
+  message("testing cpp classes")
   a <- matrix(c(0.1, 1, 2, 2), nrow = 2)
   b <- matrix(c(0, 1, 1, -1), nrow = 2)
   indiv <- list(chromosome1 = a, chromosome2 = a)
