@@ -1,6 +1,8 @@
 context("create_populations")
 
 test_that("save_population", {
+  testthat::skip_on_os("solaris")
+  message("test save_population")
   pop_size <- 100
   number_of_founders <- 10
   run_time <- 10
