@@ -1,7 +1,8 @@
 context("selection two alleles")
 
 test_that("select population two_alleles", {
-#  skip("test_selection_two_alleles")
+  testthat::skip_on_os("solaris")
+  message("test selection_two_alleles")
   select_matrix <- matrix(ncol = 5, nrow = 1)
   s <- 0.1
   select_matrix[1, ] <- c(0.05, 1.0, 1 + 0.5 * s, 1 + s, 0)
@@ -32,7 +33,8 @@ test_that("select population two_alleles", {
 })
 
 test_that("select on population", {
- # skip("test selection on population")
+  testthat::skip_on_os("solaris")
+  message("test selection on population")
   sourcepop <- simulate_admixture(pop_size = 100,
                                  number_of_founders = 10,
                                  total_runtime = 1000,
@@ -65,7 +67,8 @@ test_that("select on population", {
 
 
 test_that("select population two_alleles multiple markers", {
-  #skip("test selection multiple markers")
+  testthat::skip_on_os("solaris")
+  message("test selection multiple markers")
   select_matrix <- matrix(ncol = 5, nrow = 2)
   s <- 0.1
   select_matrix[1, ] <- c(0.25, 1.0, 1 + 0.5 * s, 1 + s, 0)
@@ -107,7 +110,8 @@ test_that("select population two_alleles multiple markers", {
 })
 
 test_that("select population two_alleles regions", {
- # skip("test population two regions")
+  testthat::skip_on_os("solaris")
+  message("test population two regions")
   select_matrix <- matrix(ncol = 5, nrow = 2)
   s <- 0.1
   select_matrix[1, ] <- c(0.25, 1.0, 1 + 0.5 * s, 1 + s, 0)
@@ -166,7 +170,8 @@ test_that("select population two_alleles regions", {
 })
 
 test_that("selection abuse", {
-  #skip("test selection abuse")
+  testthat::skip_on_os("solaris")
+  message("test selection abuse")
   sourcepop <- simulate_admixture(pop_size = 100,
                                   number_of_founders = 2,
                                   total_runtime = 100,
