@@ -1,7 +1,8 @@
 context("simulate_admixture_until")
 
 test_that("simulate_admixture_until", {
- #skip("untilll")
+  testthat::skip_on_os("solaris")
+ message("test simulate_admixture_until")
   testthat::expect_message(
     vx <- simulate_admixture_migration(total_runtime = 1000,
                                      pop_size = c(100, 100),
